.. _updatehdr:

********************************************************
UPDATEHDR: Functions for Updating WCS with New Solutions
********************************************************
The functions in this module support updating the WCS information in
distorted images with the alignment solution determined by ``TweakReg``
or saved in a shiftfile.

.. moduleauthor:: Warren Hack <help@stsci.edu>

.. automodule:: drizzlepac.updatehdr
   :members:
